@@ -24,6 +24,7 @@ from dateutil.relativedelta import relativedelta
 from nise.yaml_generators.aws.generator import AWSGenerator
 from nise.yaml_generators.azure.generator import AzureGenerator
 from nise.yaml_generators.gcp.generator import GCPGenerator
+from nise.yaml_generators.oci.generator import OCIGenerator
 from nise.yaml_generators.ocp.generator import OCPGenerator
 from nise.yaml_generators.ocp_on_cloud.generator import OCPonCloudGenerator
 
@@ -36,6 +37,7 @@ GENERATOR_MAP = {
     "AZURE": AzureGenerator(),
     "OCP-ON-CLOUD": OCPonCloudGenerator(),
     "GCP": GCPGenerator(),
+    "OCI": OCIGenerator(),
 }
 
 
@@ -93,6 +95,11 @@ def add_ocp_on_cloud_args(parser):
     add_ocp_args(parser)
 
 
+def add_oci_args(parser):
+    """Add OCI specific parser args."""
+    pass
+
+
 def add_yaml_parser_args(yaml_parser):
     """
     Initialize the argument parser.
@@ -152,6 +159,9 @@ def add_yaml_parser_args(yaml_parser):
     azure_parser = yaml_subparser.add_parser(
         "azure", parents=[parent_parser], add_help=False, description="The Azure parser", help="create the Azure yamls"
     )
+    oci_parser = yaml_subparser.add_parser(
+        "oci", parents=[parent_parser], add_help=False, description="The OCI parser", help="create the OCI yamls"
+    )
     ocp_parser = yaml_subparser.add_parser(
         "ocp", parents=[parent_parser], add_help=False, description="The OCP parser", help="create the OCP yamls"
     )
@@ -171,6 +181,7 @@ def add_yaml_parser_args(yaml_parser):
     add_gcp_args(gcp_parser)
     add_ocp_args(ocp_parser)
     add_ocp_on_cloud_args(ocp_on_cloud_parser)
+    add_oci_args(oci_parser)
 
     return yaml_parser
 
